[![DOI](https://zenodo.org/badge/4513/richlewis42/scikit-chem.svg?style=flat-square)](http://dx.doi.org/10.5281/zenodo.15919)
[![Coveralls](https://img.shields.io/coveralls/richlewis42/scikit-chem.svg?style=flat-square)](https://coveralls.io/r/richlewis42/scikit-chem)
[![Travis](https://img.shields.io/travis/richlewis42/scikit-chem.svg?style=flat-square)](https://travis-ci.org/richlewis42/scikit-chem)
[![Code Health](https://landscape.io/github/richlewis42/scikit-chem/master/landscape.svg?style=flat-square)](https://landscape.io/github/richlewis42/scikit-chem/master)
[![Release](https://img.shields.io/github/release/richlewis42/scikit-chem.svg?style=flat-square)](https://github.com/richlewis42/scikit-chem/releases)
[![License](https://img.shields.io/badge/License-BSD-blue.svg?style=flat-square)](https://github.com/richlewis42/scikit-chem/blob/master/LICENSE)

# scikit-chem

Quick attempt at more straightforwardly integrating the Scientific Python Stack with the RDKit Cheminformatics library.

- RDKit objects are inherited from, and their APIs are made more Pythonic(to an extent).
- Longer term goals are to integrate as many webservices as possible

##Note

- Work in Progress

- Speed is not high on priority list. A demonstration of the convenience is the aim - much more would be required to maintain the RDKit levels of efficiency.  The end goal of the project may be simply to feed changes back into RDKit
